package week14;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Scanner;

/** Class to represent an event, sorted by year
 *
 * @author jlepak
 */
public class Event implements Comparable<Event> {
    final public int year; // Year event occurred
    final public String desc; // Description of event

    /** Construct a new event.
     *
     * @param year  Year event occurred
     * @param desc  Description of event
     */
    public Event(int year, String desc) {
        this.year = year;
        this.desc = desc;
    }

    /** Method used to compare events by year
     * 
     * @param o Event to compare
     * @return (negative, 0, positive) depending on if this 
     *     is (less than, equal to, greater than) o
     */
    public int compareTo(Event o) {
        return new Integer(year).compareTo(o.year);
    }

    /** Nice string representation of an event.
     */
    @Override
    public String toString() {
        return String.format("%s: %s", year, desc);
    }

    // Simple test of class: read in events, then sort and print.
    public static void main(String[] args) {
        List<Event> events = new ArrayList<Event>();
        Scanner in = new Scanner(System.in);
        while (in.hasNext()) {
            String line = in.nextLine();
            if (line.charAt(0) == 'q')
                break;
            int year = Integer.parseInt(line);
            String desc = in.nextLine();
            events.add(new Event(year, desc));
        }
        Collections.sort(events);
        for (Event e : events) {
            System.out.println(e);
        }
    }
}
