package week14;

import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.table.AbstractTableModel;
import javax.swing.table.TableModel;

/** Simple example to enter and sort Events
 *
 * @author jlepak
 */
public class GuiExample extends JFrame {

    final private JButton submit; // Button to submit new event
    final private JLabel yearLabel; // Label for year entry
    final private JLabel descLabel; // Label for description entry
    final private JTextField yearField; // Year entry
    final private JTextField descField; // Description entry
    final private JTable table;  // Table to display all events
    final private JScrollPane scroll; // Scroll panel for table
    final private List<Event> events; // All entered events

    public GuiExample() {
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

        // Panels for organizing groups of elements
        JPanel main = new JPanel();
        JPanel input = new JPanel(new GridLayout(0, 2));

        // Create gui elements
        yearLabel = new JLabel("Year");
        descLabel = new JLabel("Description");
        yearField = new JTextField();
        descField = new JTextField();
        events = new ArrayList<Event>();
        table = buildTable();
        scroll = new JScrollPane(table);
        submit = new JButton("submit");

        // Add click handler for button
        submit.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                Event event = new Event(Integer.parseInt(yearField.getText()),
                        descField.getText());
                events.add(event);
                System.out.println(event);
                Collections.sort(events);
                ((AbstractTableModel)table.getModel()).fireTableDataChanged();
            }
        });

        // Add elements to panels
        input.add(yearLabel);
        input.add(yearField);
        input.add(descLabel);
        input.add(descField);
        input.add(submit);
        main.add(input);
        main.add(scroll);

        add(main);
        pack();
    }

    /** Build event table by creating model
     */
    private JTable buildTable() {
        TableModel model = new AbstractTableModel() {
            public String[] colNames = {"Year", "Description"};
            @Override
            public String getColumnName(int col) {
                return colNames[col];
            }
            public int getRowCount() {
                return events.size();
            }
            public int getColumnCount() {
                return 2;
            }
            public Object getValueAt(int rowIndex, int columnIndex) {
                // Return year for column 0, description for column 1
                return columnIndex == 0 ? events.get(rowIndex).year
                        : events.get(rowIndex).desc;
            }
        };
        return new JTable(model);
    }

    public static void main(String[] args) {
        // Standard way to start a GUI application.  This function is used
        // so that all program logic is handled by the single GUI thread.
        javax.swing.SwingUtilities.invokeLater(new Runnable() {
            public void run() {
                new GuiExample().setVisible(true);
            }
        });
    }
   
}