package week14;

import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JTextField;

/** Simple example to enter and sort Events
 *
 * @author jlepak
 */
public class SimpleGuiExample extends JFrame {

    final private JButton submit; // Button to submit new event
    final private JLabel yearLabel; // Label for year entry
    final private JLabel descLabel; // Label for description entry
    final private JTextField yearField; // Year entry
    final private JTextField descField; // Description entry
    final private List<Event> events; // All entered events

    /** Create click handler that adds new event, sorts the events,
     *  and prints all stored events.
     */
    private ActionListener clickHandler() {
        return new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                Event event = new Event(Integer.parseInt(yearField.getText()),
                        descField.getText());
                events.add(event);
                Collections.sort(events);
                printEvents();
            }
        };
    }

    private void printEvents() {
        for (Event e : events)
            System.out.println(e);
        System.out.println();
    }

    public SimpleGuiExample() {
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setLayout(new GridLayout(0, 2));

        // Create gui elements
        yearLabel = new JLabel("Year");
        descLabel = new JLabel("Description");
        yearField = new JTextField();
        descField = new JTextField();
        events = new ArrayList<Event>();
        submit = new JButton("submit");

        // Add click handler for button
        submit.addActionListener(clickHandler());

        // Add elements to panels
        add(yearLabel);
        add(yearField);
        add(descLabel);
        add(descField);
        add(submit);
        pack();
    }

    public static void main(String[] args) {
        // Standard way to start a GUI application.  This function is used
        // so that all program logic is handled by the single GUI thread.
        javax.swing.SwingUtilities.invokeLater(new Runnable() {
            public void run() {
                new SimpleGuiExample().setVisible(true);
            }
        });
    }

}